@@ -34,5 +34,7 @@ models <- lapply(datasets, function(dat){
 meta_analysis <- metagam(models, grid_size = 500, terms = "s(x2)", intercept = TRUE)
 
 ## -----------------------------------------------------------------------------
-plot_dominance(meta_analysis)
+library(viridis)
+plot_dominance(meta_analysis) +
+  scale_fill_viridis(discrete = TRUE)
 
